package org.rcisoft.bus.wmsgoods.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtilAsp;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.bus.wmsgoods.dao.WmsGoodsRepository;
import org.rcisoft.bus.wmsgoods.entity.WmsGoods;
import org.rcisoft.bus.wmsgoods.service.WmsGoodsService;
import org.rcisoft.core.service.CyBaseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2024年5月29日 下午1:21:49.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class WmsGoodsServiceImpl extends ServiceImpl<WmsGoodsRepository,WmsGoods>  implements WmsGoodsService {


    /**
    * 保存 商品信息表
    * @param wmsGoods
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(WmsGoods wmsGoods){
        //增加操作
        int line = baseMapper.insert(wmsGoods);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            wmsGoods.getBusinessId()+"的商品信息表信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 商品信息表
    * @param wmsGoods
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(WmsGoods wmsGoods){
        int line = baseMapper.realDelete(wmsGoods);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            wmsGoods.getBusinessId()+"的商品信息表信息");
        return new CyPersistModel(line);
    }

    /**
    * 逻辑删除 商品信息表
    * @param wmsGoods
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(WmsGoods wmsGoods){
        wmsGoods.setDeleted();
        int line = baseMapper.deleteById(wmsGoods);
            log.debug(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
                wmsGoods.getBusinessId()+"的商品信息表信息");
            return new CyPersistModel(line);
    }

    /**
    * 修改 商品信息表
    * @param wmsGoods
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(WmsGoods wmsGoods){
        int line = baseMapper.updateById(wmsGoods);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ wmsGoods.getBusinessId()+"的商品信息表信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 商品信息表
    * @param id
    * @return
    */
    @Override
    public WmsGoods findById(int id){
        return baseMapper.selectById(id);
    }

    /**
    * 分页查询 商品信息表
    * @param wmsGoods
    * @return
    */
    @Override
    public IPage<WmsGoods> findAllByPagination(CyPageInfo<WmsGoods> paginationUtility,
        WmsGoods wmsGoods){
        return baseMapper.queryWmsGoodssPaged(paginationUtility,wmsGoods);

    }

    /**
    * 查询list 商品信息表
    * @param wmsGoods
    * @return
    */
    @Override
    public List<WmsGoods> findAll(WmsGoods wmsGoods){
        return baseMapper.queryWmsGoodss(wmsGoods);

    }

    /**
    * 导出商品信息表
    * @return
    */
    @Override
    public List<WmsGoods> export(WmsGoods wmsGoods) {
        List<WmsGoods> wmsGoodsList = baseMapper.queryWmsGoodss(wmsGoods);
        return wmsGoodsList;
    }

}
