package org.rcisoft.bus.wmsgoodsapply.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.bus.util.EpExcelUtil;
import org.rcisoft.bus.wmsgoodsapply.dto.ExportEntryDto;
import org.rcisoft.bus.wmsgoodsapply.dto.ImportGoodsTempDto;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtilAsp;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.bus.wmsgoodsapply.dao.WmsGoodsApplyRepository;
import org.rcisoft.bus.wmsgoodsapply.entity.WmsGoodsApply;
import org.rcisoft.bus.wmsgoodsapply.service.WmsGoodsApplyService;
import org.rcisoft.core.service.CyBaseService;

import org.rcisoft.sys.dictionary.dao.DictDataRepository;
import org.rcisoft.sys.dictionary.dto.DictDataDTO;
import org.rcisoft.sys.dictionary.entity.DictData;
import org.rcisoft.sys.rbac.user.enums.UserInfoExceptionEnums;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import lombok.extern.slf4j.Slf4j;
import org.springframework.util.ObjectUtils;
import org.springframework.web.multipart.MultipartFile;

/**
 * Created by cy on 2024年5月29日 下午1:21:49.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class WmsGoodsApplyServiceImpl extends ServiceImpl<WmsGoodsApplyRepository,WmsGoodsApply>  implements WmsGoodsApplyService {
    @Autowired
    private DictDataRepository dictDataRepository;

    /**
    * 保存 商品申请表
    * @param wmsGoodsApply
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(WmsGoodsApply wmsGoodsApply){
        //增加操作
        int line = baseMapper.insert(wmsGoodsApply);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            wmsGoodsApply.getBusinessId()+"的商品申请表信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 商品申请表
    * @param wmsGoodsApply
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(WmsGoodsApply wmsGoodsApply){
        int line = baseMapper.realDelete(wmsGoodsApply);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            wmsGoodsApply.getBusinessId()+"的商品申请表信息");
        return new CyPersistModel(line);
    }

    /**
    * 逻辑删除 商品申请表
    * @param wmsGoodsApply
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(WmsGoodsApply wmsGoodsApply){
        wmsGoodsApply.setDeleted();
        int line = baseMapper.deleteById(wmsGoodsApply);
            log.debug(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
                wmsGoodsApply.getBusinessId()+"的商品申请表信息");
            return new CyPersistModel(line);
    }

    /**
    * 修改 商品申请表
    * @param wmsGoodsApply
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(WmsGoodsApply wmsGoodsApply){
        int line = baseMapper.updateById(wmsGoodsApply);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ wmsGoodsApply.getBusinessId()+"的商品申请表信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 商品申请表
    * @param id
    * @return
    */
    @Override
    public WmsGoodsApply findById(int id){
        return baseMapper.selectById(id);
    }

    /**
    * 分页查询 商品申请表
    * @param wmsGoodsApply
    * @return
    */
    @Override
    public IPage<WmsGoodsApply> findAllByPagination(CyPageInfo<WmsGoodsApply> paginationUtility,
        WmsGoodsApply wmsGoodsApply){
        return baseMapper.queryWmsGoodsApplysPaged(paginationUtility,wmsGoodsApply);

    }

    /**
    * 查询list 商品申请表
    * @param wmsGoodsApply
    * @return
    */
    @Override
    public List<WmsGoodsApply> findAll(WmsGoodsApply wmsGoodsApply){
        return baseMapper.queryWmsGoodsApplys(wmsGoodsApply);

    }

    /**
    * 导出商品申请表
    * @return
    */
    @Override
    public List<WmsGoodsApply> export(WmsGoodsApply wmsGoodsApply) {
        List<WmsGoodsApply> wmsGoodsApplyList = baseMapper.queryWmsGoodsApplys(wmsGoodsApply);
        return wmsGoodsApplyList;
    }

    @Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
    @Override
    public ImportGoodsTempDto importGoodsExcel(MultipartFile file) {
        // 错误集合
        List<String> errors = new ArrayList<>();

        // 将excel文件转换为list集合
        List<ExportEntryDto> dataList = EpExcelUtil.importExcelNotTitle(file, 1, 1, ExportEntryDto.class);
        // 判断文件的信息是否存在 这种方法的效率太慢 但是可以用

        if (dataList.isEmpty()){
            throw new CyServiceException(UserInfoExceptionEnums.EXCEL_NULL);
        }
        /**
         * 进行校验 校验规则如下
         * 1.单号 PN lot rank 数量 备注 都是必填 如果有一个为空 将其过滤掉
         * 2.数量为正整数
         * 3.仓库如果匹配不上 或者为空 按第一个仓库走
         * 4.成功返回了多少条
         * **/

        // 要添加的数据集合
        List<WmsGoodsApply> addGoodsList = new ArrayList<>();
        // 获取code的初值
        // 获取当前时间
        Date date = new Date();
        // 设置日期格式
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMdd");
        // 格式化日期
         sdf.format(date);
        for (int i = 0; i<dataList.size() ;i++) {
            WmsGoodsApply one = new WmsGoodsApply();

            // goodscode 都是必填 如果有一个为空 过滤起数据

            if (StringUtils.isNotBlank(dataList.get(i).getGoodsCode())) {
                BeanUtils.copyProperties(dataList.get(i),one);
                // 将空格和回车去掉
                one.setGoodsCode(this.removeSymbol(one.getGoodsCode()));
                // 获取全部厂家的map


                if (!ObjectUtils.isEmpty(one)) {
                    addGoodsList.add(one);
                }
            }
        }
        // 获取所有仓库数据
        DictDataDTO dictData = new DictDataDTO();
        dictData.setFlag("1");
        dictData.setDictType("GOODS_TYPE");
        List<DictData> dictDataList = dictDataRepository.querySysDictDatas(dictData);
        if (dictDataList.isEmpty()) errors.add("请在数据字典中添加仓库字典数据");
        if (!errors.isEmpty()) {
            throw new CyServiceException(503,errors.get(0));
        }
        // 处理要添加的数据
        log.info("addJbapplyTempList: {}",addGoodsList);
        ImportGoodsTempDto importGoodsTempDto = new ImportGoodsTempDto();
        if (addGoodsList.isEmpty()) {
            importGoodsTempDto.setRows(0);
            importGoodsTempDto.setTotal(dataList.size());
            return importGoodsTempDto;
        }
        addGoodsList.forEach(item -> {
            item.setCreateBy(CyUserUtil.getAuthenBusinessId());
            item.setCreateDate(new Date());
            item.setUpdateBy(CyUserUtil.getAuthenBusinessId());
            item.setUpdateDate(new Date());
            item.setDealStatus("0");
            item.setFlag("1");
            if (item.getGoodsType() == null) {
                item.setGoodsType(dictDataList.get(0).getDictValue());
            } else {
                // 将仓库值转换成value值
                QueryWrapper<DictData> queryWrapper = new QueryWrapper<>();
                queryWrapper.eq("dict_type","GOODS_TYPE");
                queryWrapper.eq("dict_label",item.getGoodsType());
                List<DictData> GoodsTypeData = dictDataRepository.selectList(queryWrapper);
                if (GoodsTypeData.isEmpty()) {
                    item.setGoodsType(dictDataList.get(0).getDictValue());
                } else {
                    item.setGoodsType(GoodsTypeData.get(0).getDictValue());
                }
            }
        });
        // 批量插入
        baseMapper.batchAdd(addGoodsList);
        importGoodsTempDto.setTotal(dataList.size());
        importGoodsTempDto.setRows(addGoodsList.size());
        return importGoodsTempDto;
    }
    private String removeSymbol(String source) {
        String target = null;
        target = source.replaceAll("\\s*|\r|\n|\t","");
        if (target.contains(" ")) {
            target.replaceAll(" ","");
        }
        return target;
    }
    public Boolean isPositiveInteger(String figure) {
        // 如果输入为空，或者不是数字，则返回 false
        if (figure == null || figure.isEmpty()) {
            return false;
        }
        // 遍历字符串中的每个字符，检查是否都是数字
        for (char c : figure.toCharArray()) {
            if (!Character.isDigit(c)) {
                return false;
            }
        }
        // 将字符串转换为整数
        int num = Integer.parseInt(figure);
        // 如果大于 0 则为正整数，否则为非正整数
        return num > 0;
    }
}
