package org.rcisoft.bus.wmsgoodslog.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import org.rcisoft.bus.wmsgoodslog.entity.WmsGoodsLog;
import org.rcisoft.bus.wmsgoodslog.service.WmsGoodsLogService;

import java.util.List;

/**
* Created by cy on 2024年5月29日 下午1:21:49.
*/
@RestController
@RequestMapping("/wmsgoodslog")
public class WmsGoodsLogController extends CyPaginationController<WmsGoodsLog> {


    @Autowired
    private WmsGoodsLogService wmsGoodsLogServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsLog:add')")
    @CyOpeLogAnno(title = "system-商品记录表管理-新增商品记录表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加商品记录表", notes="添加商品记录表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid WmsGoodsLog wmsGoodsLog, BindingResult bindingResult) {
        CyPersistModel data = wmsGoodsLogServiceImpl.persist(wmsGoodsLog);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        wmsGoodsLog);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsLog:delete')")
    @CyOpeLogAnno(title = "system-商品记录表管理-删除商品记录表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="逻辑删除商品记录表", notes="逻辑删除商品记录表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable int businessId,WmsGoodsLog wmsGoodsLog) {
        wmsGoodsLog.setBusinessId(businessId);
        CyPersistModel data = wmsGoodsLogServiceImpl.removeLogical(wmsGoodsLog);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsLog:delete')")
    @CyOpeLogAnno(title = "system-商品记录表管理-删除商品记录表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除商品记录表", notes="删除商品记录表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId,WmsGoodsLog wmsGoodsLog) {
        wmsGoodsLog.setBusinessId(businessId);
        CyPersistModel data = wmsGoodsLogServiceImpl.remove(wmsGoodsLog);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsLog:update')")
    @CyOpeLogAnno(title = "system-商品记录表管理-修改商品记录表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改商品记录表", notes="修改商品记录表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @Valid WmsGoodsLog wmsGoodsLog, BindingResult bindingResult) {
        wmsGoodsLog.setBusinessId(businessId);
        CyPersistModel data = wmsGoodsLogServiceImpl.merge(wmsGoodsLog);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        wmsGoodsLog);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsLog:query')")
    @CyOpeLogAnno(title = "system-商品记录表管理-查询商品记录表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一商品记录表", notes="查询单一商品记录表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        wmsGoodsLogServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsLog:list')")
    @CyOpeLogAnno(title = "system-商品记录表管理-查询商品记录表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询商品记录表集合", notes="查询商品记录表集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(WmsGoodsLog wmsGoodsLog) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            wmsGoodsLogServiceImpl.findAll(wmsGoodsLog));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:goodsLog:list')")
    @CyOpeLogAnno(title = "system-商品记录表管理-查询商品记录表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询商品记录表集合", notes="分页查询商品记录表集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(WmsGoodsLog wmsGoodsLog) {
        wmsGoodsLogServiceImpl.findAllByPagination(getPaginationUtility(), wmsGoodsLog);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-商品记录表管理-查询商品记录表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出商品记录表信息", notes = "导出商品记录表信息")
    @GetMapping(value = "/export")
    public void outWmsGoodsLog(HttpServletResponse response,WmsGoodsLog wmsGoodsLog,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="商品记录表信息.xls";break;
            case "1": excelName="商品记录表信息.xlsx";break;
            case "2": excelName="商品记录表信息.csv";break;
        }
        List<WmsGoodsLog> wmsGoodsLogList = wmsGoodsLogServiceImpl.export(wmsGoodsLog);
        CyEpExcelUtil.exportExcel(wmsGoodsLogList, "商品记录表信息", "商品记录表信息", WmsGoodsLog.class, excelName, response);
    }
}
