package org.rcisoft.bus.wmsgoodsstock.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtilAsp;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.bus.wmsgoodsstock.dao.WmsGoodsStockRepository;
import org.rcisoft.bus.wmsgoodsstock.entity.WmsGoodsStock;
import org.rcisoft.bus.wmsgoodsstock.service.WmsGoodsStockService;
import org.rcisoft.core.service.CyBaseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2024年5月29日 下午1:21:49.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class WmsGoodsStockServiceImpl extends ServiceImpl<WmsGoodsStockRepository,WmsGoodsStock>  implements WmsGoodsStockService {


    /**
    * 保存 库存管理表
    * @param wmsGoodsStock
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(WmsGoodsStock wmsGoodsStock){
        //增加操作
        int line = baseMapper.insert(wmsGoodsStock);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            wmsGoodsStock.getBusinessId()+"的库存管理表信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 库存管理表
    * @param wmsGoodsStock
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(WmsGoodsStock wmsGoodsStock){
        int line = baseMapper.realDelete(wmsGoodsStock);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            wmsGoodsStock.getBusinessId()+"的库存管理表信息");
        return new CyPersistModel(line);
    }

    /**
    * 逻辑删除 库存管理表
    * @param wmsGoodsStock
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(WmsGoodsStock wmsGoodsStock){
        wmsGoodsStock.setDeleted();
        int line = baseMapper.deleteById(wmsGoodsStock);
            log.debug(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
                wmsGoodsStock.getBusinessId()+"的库存管理表信息");
            return new CyPersistModel(line);
    }

    /**
    * 修改 库存管理表
    * @param wmsGoodsStock
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(WmsGoodsStock wmsGoodsStock){
        int line = baseMapper.updateById(wmsGoodsStock);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ wmsGoodsStock.getBusinessId()+"的库存管理表信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 库存管理表
    * @param id
    * @return
    */
    @Override
    public WmsGoodsStock findById(int id){
        return baseMapper.selectById(id);
    }

    /**
    * 分页查询 库存管理表
    * @param wmsGoodsStock
    * @return
    */
    @Override
    public IPage<WmsGoodsStock> findAllByPagination(CyPageInfo<WmsGoodsStock> paginationUtility,
        WmsGoodsStock wmsGoodsStock){
        return baseMapper.queryWmsGoodsStocksPaged(paginationUtility,wmsGoodsStock);

    }

    /**
    * 查询list 库存管理表
    * @param wmsGoodsStock
    * @return
    */
    @Override
    public List<WmsGoodsStock> findAll(WmsGoodsStock wmsGoodsStock){
        return baseMapper.queryWmsGoodsStocks(wmsGoodsStock);

    }

    /**
    * 导出库存管理表
    * @return
    */
    @Override
    public List<WmsGoodsStock> export(WmsGoodsStock wmsGoodsStock) {
        List<WmsGoodsStock> wmsGoodsStockList = baseMapper.queryWmsGoodsStocks(wmsGoodsStock);
        return wmsGoodsStockList;
    }

}
